<?php

/**
 * @file
 *   drush command to download Pixlr Javascript library.
 */

/**
 * The Pixlr javascript library URI.
 */
define('PIXLR_DOWNLOAD_URI', 'http://pixlr.com/lib/pixlr.js');

/**
 * Implementation of hook_drush_command().
 *
 * In this hook, you specify which commands your
 * drush module makes available, what it does and
 * description.
 *
 * Notice how this structure closely resembles how
 * you define menu hooks.
 *
 * @See drush_parse_command() for a list of recognized keys.
 *
 * @return
 *   An associative array describing your command(s).
 */
function pixlr_drush_command() {
  $items = array();

  // the key in the $items array is the name of the command.
  $items['pixlr-library'] = array(
    'callback' => 'drush_pixlr_library',
    'description' => dt("Downloads Pixlr Javascript library."),
    'arguments' => array(
      'path' => dt('Optional. A path where to install Pixlr library. If omitted Drush will use the default location: /sites/all/libraries.'),
    ),
  );

  return $items;
}

/**
 * Implementation of hook_drush_help().
 *
 * This function is called whenever a drush user calls
 * 'drush help <name-of-your-command>'
 *
 * @param
 *   A string with the help section (prepend with 'drush:')
 *
 * @return
 *   A string with the help text for your command.
 */
function pixlr_drush_help($section) {
  switch ($section) {
    case 'drush:pixlr-library':
      return dt("Downloads the Pixlr Javascript library from pixlr.com, default download location is sites/all/libraries.");
  }
}

/**
 * Command to download the Pixlr library.
 */
function drush_pixlr_library() {
//  if (!drush_shell_exec('type unzip')) {
//    return drush_set_error(dt('Missing dependency: unzip. Install it before using this command.'));
//  }

  // Setting download location.
  $args = func_get_args();
  if ($args[0]) {
    $path = $args[0];
  }
  else {
    $path = 'sites/all/libraries';
  }

  // Create the path if it does not exist.
  if (!is_dir($path)) {
    drush_op('mkdir', $path);
    drush_log(dt('Directory @path was created', array('@path' => $path)), 'notice');
  }

  // Set the directory to the download location.
  $olddir = getcwd();
  chdir($path);

  $filename = basename(PIXLR_DOWNLOAD_URI);
  $dirname = basename(PIXLR_DOWNLOAD_URI, '.js');

  if (is_dir($dirname)) {
    chdir($dirname);
    // Remove any existing Pixlr library
    if (is_file($filename)) {
      drush_log(dt('An existing Pixlr library was overwritten at @path', array('@path' => $path)), 'notice');
      drush_op('unlink', $filename);
    }
  }
  else {
    drush_op('mkdir', $dirname);
    chdir($dirname);
  }

  // Download the Pixlr library
  if (!drush_shell_exec('wget '. PIXLR_DOWNLOAD_URI)) {
    drush_shell_exec('curl -O '. PIXLR_DOWNLOAD_URI);
  }

  // Set working directory back to the previous working directory.
  chdir($olddir);

  if (is_dir($path .'/'. $dirname)) {
    drush_log(dt('Pixlr library has been downloaded to @path', array('@path' => $path)), 'success');
  }
  else {
    drush_log(dt('Drush was unable to download Pixlr library to @path', array('@path' => $path)), 'error');
  }
}

